@@ -10,11 +10,11 @@ Usage::
     client: ComprehendMedicalClient = boto3.client("comprehendmedical")
     ```
 """
-import sys
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_comprehendmedical.literals import LanguageCode
 from mypy_boto3_comprehendmedical.type_defs import (
     ComprehendMedicalAsyncJobFilterTypeDef,
     DescribeEntitiesDetectionV2JobResponseTypeDef,
@@ -42,12 +42,6 @@ from mypy_boto3_comprehendmedical.type_defs import (
     StopRxNormInferenceJobResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ComprehendMedicalClient",)
 
 
@@ -73,7 +67,7 @@ class Exceptions:
 
 class ComprehendMedicalClient:
     """
-    [ComprehendMedical.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client)
+    [ComprehendMedical.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client)
     """
 
     meta: ClientMeta
@@ -81,48 +75,48 @@ class ComprehendMedicalClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
         """
 
     def describe_entities_detection_v2_job(
         self, JobId: str
     ) -> DescribeEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.describe_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
+        [Client.describe_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
         """
 
     def describe_icd10_cm_inference_job(
         self, JobId: str
     ) -> DescribeICD10CMInferenceJobResponseTypeDef:
         """
-        [Client.describe_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
+        [Client.describe_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
         """
 
     def describe_phi_detection_job(self, JobId: str) -> DescribePHIDetectionJobResponseTypeDef:
         """
-        [Client.describe_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
+        [Client.describe_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
         """
 
     def describe_rx_norm_inference_job(
         self, JobId: str
     ) -> DescribeRxNormInferenceJobResponseTypeDef:
         """
-        [Client.describe_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
+        [Client.describe_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
         """
 
     def detect_entities(self, Text: str) -> DetectEntitiesResponseTypeDef:
         """
-        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
+        [Client.detect_entities documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
         """
 
     def detect_entities_v2(self, Text: str) -> DetectEntitiesV2ResponseTypeDef:
         """
-        [Client.detect_entities_v2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
+        [Client.detect_entities_v2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
         """
 
     def detect_phi(self, Text: str) -> DetectPHIResponseTypeDef:
         """
-        [Client.detect_phi documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
+        [Client.detect_phi documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
         """
 
     def generate_presigned_url(
@@ -133,17 +127,17 @@ class ComprehendMedicalClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
         """
 
     def infer_icd10_cm(self, Text: str) -> InferICD10CMResponseTypeDef:
         """
-        [Client.infer_icd10_cm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
+        [Client.infer_icd10_cm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
         """
 
     def infer_rx_norm(self, Text: str) -> InferRxNormResponseTypeDef:
         """
-        [Client.infer_rx_norm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
+        [Client.infer_rx_norm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
         """
 
     def list_entities_detection_v2_jobs(
@@ -153,7 +147,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListEntitiesDetectionV2JobsResponseTypeDef:
         """
-        [Client.list_entities_detection_v2_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
+        [Client.list_entities_detection_v2_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
         """
 
     def list_icd10_cm_inference_jobs(
@@ -163,7 +157,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListICD10CMInferenceJobsResponseTypeDef:
         """
-        [Client.list_icd10_cm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
+        [Client.list_icd10_cm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
         """
 
     def list_phi_detection_jobs(
@@ -173,7 +167,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListPHIDetectionJobsResponseTypeDef:
         """
-        [Client.list_phi_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
+        [Client.list_phi_detection_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
         """
 
     def list_rx_norm_inference_jobs(
@@ -183,7 +177,7 @@ class ComprehendMedicalClient:
         MaxResults: int = None,
     ) -> ListRxNormInferenceJobsResponseTypeDef:
         """
-        [Client.list_rx_norm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
+        [Client.list_rx_norm_inference_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
         """
 
     def start_entities_detection_v2_job(
@@ -191,13 +185,13 @@ class ComprehendMedicalClient:
         InputDataConfig: "InputDataConfigTypeDef",
         OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
-        LanguageCode: Literal["en"],
+        LanguageCode: LanguageCode,
         JobName: str = None,
         ClientRequestToken: str = None,
         KMSKey: str = None,
     ) -> StartEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.start_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
+        [Client.start_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
         """
 
     def start_icd10_cm_inference_job(
@@ -205,13 +199,13 @@ class ComprehendMedicalClient:
         InputDataConfig: "InputDataConfigTypeDef",
         OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
-        LanguageCode: Literal["en"],
+        LanguageCode: LanguageCode,
         JobName: str = None,
         ClientRequestToken: str = None,
         KMSKey: str = None,
     ) -> StartICD10CMInferenceJobResponseTypeDef:
         """
-        [Client.start_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
+        [Client.start_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
         """
 
     def start_phi_detection_job(
@@ -219,13 +213,13 @@ class ComprehendMedicalClient:
         InputDataConfig: "InputDataConfigTypeDef",
         OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
-        LanguageCode: Literal["en"],
+        LanguageCode: LanguageCode,
         JobName: str = None,
         ClientRequestToken: str = None,
         KMSKey: str = None,
     ) -> StartPHIDetectionJobResponseTypeDef:
         """
-        [Client.start_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
+        [Client.start_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
         """
 
     def start_rx_norm_inference_job(
@@ -233,33 +227,33 @@ class ComprehendMedicalClient:
         InputDataConfig: "InputDataConfigTypeDef",
         OutputDataConfig: "OutputDataConfigTypeDef",
         DataAccessRoleArn: str,
-        LanguageCode: Literal["en"],
+        LanguageCode: LanguageCode,
         JobName: str = None,
         ClientRequestToken: str = None,
         KMSKey: str = None,
     ) -> StartRxNormInferenceJobResponseTypeDef:
         """
-        [Client.start_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
+        [Client.start_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
         """
 
     def stop_entities_detection_v2_job(
         self, JobId: str
     ) -> StopEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Client.stop_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
+        [Client.stop_entities_detection_v2_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
         """
 
     def stop_icd10_cm_inference_job(self, JobId: str) -> StopICD10CMInferenceJobResponseTypeDef:
         """
-        [Client.stop_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
+        [Client.stop_icd10_cm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
         """
 
     def stop_phi_detection_job(self, JobId: str) -> StopPHIDetectionJobResponseTypeDef:
         """
-        [Client.stop_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
+        [Client.stop_phi_detection_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
         """
 
     def stop_rx_norm_inference_job(self, JobId: str) -> StopRxNormInferenceJobResponseTypeDef:
         """
-        [Client.stop_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.55/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
+        [Client.stop_rx_norm_inference_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
         """
