@@ -13,10 +13,24 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_comprehendmedical.literals import (
+    AttributeName,
+    EntitySubType,
+    EntityType,
+    ICD10CMAttributeType,
+    ICD10CMEntityCategory,
+    ICD10CMEntityType,
+    ICD10CMRelationshipType,
+    ICD10CMTraitName,
+    JobStatus,
+    LanguageCode,
+    RelationshipType,
+    RxNormAttributeType,
+    RxNormEntityCategory,
+    RxNormEntityType,
+    RxNormTraitName,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -66,76 +80,15 @@ __all__ = (
 AttributeTypeDef = TypedDict(
     "AttributeTypeDef",
     {
-        "Type": Literal[
-            "NAME",
-            "DOSAGE",
-            "ROUTE_OR_MODE",
-            "FORM",
-            "FREQUENCY",
-            "DURATION",
-            "GENERIC_NAME",
-            "BRAND_NAME",
-            "STRENGTH",
-            "RATE",
-            "ACUITY",
-            "TEST_NAME",
-            "TEST_VALUE",
-            "TEST_UNITS",
-            "PROCEDURE_NAME",
-            "TREATMENT_NAME",
-            "DATE",
-            "AGE",
-            "CONTACT_POINT",
-            "EMAIL",
-            "IDENTIFIER",
-            "URL",
-            "ADDRESS",
-            "PROFESSION",
-            "SYSTEM_ORGAN_SITE",
-            "DIRECTION",
-            "QUALITY",
-            "QUANTITY",
-            "TIME_EXPRESSION",
-            "TIME_TO_MEDICATION_NAME",
-            "TIME_TO_DX_NAME",
-            "TIME_TO_TEST_NAME",
-            "TIME_TO_PROCEDURE_NAME",
-            "TIME_TO_TREATMENT_NAME",
-        ],
+        "Type": EntitySubType,
         "Score": float,
         "RelationshipScore": float,
-        "RelationshipType": Literal[
-            "EVERY",
-            "WITH_DOSAGE",
-            "ADMINISTERED_VIA",
-            "FOR",
-            "NEGATIVE",
-            "OVERLAP",
-            "DOSAGE",
-            "ROUTE_OR_MODE",
-            "FORM",
-            "FREQUENCY",
-            "DURATION",
-            "STRENGTH",
-            "RATE",
-            "ACUITY",
-            "TEST_VALUE",
-            "TEST_UNITS",
-            "DIRECTION",
-            "SYSTEM_ORGAN_SITE",
-        ],
+        "RelationshipType": RelationshipType,
         "Id": int,
         "BeginOffset": int,
         "EndOffset": int,
         "Text": str,
-        "Category": Literal[
-            "MEDICATION",
-            "MEDICAL_CONDITION",
-            "PROTECTED_HEALTH_INFORMATION",
-            "TEST_TREATMENT_PROCEDURE",
-            "ANATOMY",
-            "TIME_EXPRESSION",
-        ],
+        "Category": EntityType,
         "Traits": List["TraitTypeDef"],
     },
     total=False,
@@ -146,22 +99,14 @@ ComprehendMedicalAsyncJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED",
-            "IN_PROGRESS",
-            "COMPLETED",
-            "PARTIAL_SUCCESS",
-            "FAILED",
-            "STOP_REQUESTED",
-            "STOPPED",
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
         "ExpirationTime": datetime,
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
-        "LanguageCode": Literal["en"],
+        "LanguageCode": LanguageCode,
         "DataAccessRoleArn": str,
         "ManifestFilePath": str,
         "KMSKey": str,
@@ -178,50 +123,8 @@ EntityTypeDef = TypedDict(
         "EndOffset": int,
         "Score": float,
         "Text": str,
-        "Category": Literal[
-            "MEDICATION",
-            "MEDICAL_CONDITION",
-            "PROTECTED_HEALTH_INFORMATION",
-            "TEST_TREATMENT_PROCEDURE",
-            "ANATOMY",
-            "TIME_EXPRESSION",
-        ],
-        "Type": Literal[
-            "NAME",
-            "DOSAGE",
-            "ROUTE_OR_MODE",
-            "FORM",
-            "FREQUENCY",
-            "DURATION",
-            "GENERIC_NAME",
-            "BRAND_NAME",
-            "STRENGTH",
-            "RATE",
-            "ACUITY",
-            "TEST_NAME",
-            "TEST_VALUE",
-            "TEST_UNITS",
-            "PROCEDURE_NAME",
-            "TREATMENT_NAME",
-            "DATE",
-            "AGE",
-            "CONTACT_POINT",
-            "EMAIL",
-            "IDENTIFIER",
-            "URL",
-            "ADDRESS",
-            "PROFESSION",
-            "SYSTEM_ORGAN_SITE",
-            "DIRECTION",
-            "QUALITY",
-            "QUANTITY",
-            "TIME_EXPRESSION",
-            "TIME_TO_MEDICATION_NAME",
-            "TIME_TO_DX_NAME",
-            "TIME_TO_TEST_NAME",
-            "TIME_TO_PROCEDURE_NAME",
-            "TIME_TO_TREATMENT_NAME",
-        ],
+        "Category": EntityType,
+        "Type": EntitySubType,
         "Traits": List["TraitTypeDef"],
         "Attributes": List["AttributeTypeDef"],
     },
@@ -231,15 +134,7 @@ EntityTypeDef = TypedDict(
 ICD10CMAttributeTypeDef = TypedDict(
     "ICD10CMAttributeTypeDef",
     {
-        "Type": Literal[
-            "ACUITY",
-            "DIRECTION",
-            "SYSTEM_ORGAN_SITE",
-            "QUALITY",
-            "QUANTITY",
-            "TIME_TO_DX_NAME",
-            "TIME_EXPRESSION",
-        ],
+        "Type": ICD10CMAttributeType,
         "Score": float,
         "RelationshipScore": float,
         "Id": int,
@@ -247,8 +142,8 @@ ICD10CMAttributeTypeDef = TypedDict(
         "EndOffset": int,
         "Text": str,
         "Traits": List["ICD10CMTraitTypeDef"],
-        "Category": Literal["DX_NAME", "TIME_EXPRESSION"],
-        "RelationshipType": Literal["OVERLAP", "SYSTEM_ORGAN_SITE"],
+        "Category": ICD10CMEntityType,
+        "RelationshipType": ICD10CMRelationshipType,
     },
     total=False,
 )
@@ -262,8 +157,8 @@ ICD10CMEntityTypeDef = TypedDict(
     {
         "Id": int,
         "Text": str,
-        "Category": Literal["MEDICAL_CONDITION"],
-        "Type": Literal["DX_NAME", "TIME_EXPRESSION"],
+        "Category": ICD10CMEntityCategory,
+        "Type": ICD10CMEntityType,
         "Score": float,
         "BeginOffset": int,
         "EndOffset": int,
@@ -275,9 +170,7 @@ ICD10CMEntityTypeDef = TypedDict(
 )
 
 ICD10CMTraitTypeDef = TypedDict(
-    "ICD10CMTraitTypeDef",
-    {"Name": Literal["NEGATION", "DIAGNOSIS", "SIGN", "SYMPTOM"], "Score": float},
-    total=False,
+    "ICD10CMTraitTypeDef", {"Name": ICD10CMTraitName, "Score": float}, total=False
 )
 
 _RequiredInputDataConfigTypeDef = TypedDict("_RequiredInputDataConfigTypeDef", {"S3Bucket": str})
@@ -303,9 +196,7 @@ class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputD
 RxNormAttributeTypeDef = TypedDict(
     "RxNormAttributeTypeDef",
     {
-        "Type": Literal[
-            "DOSAGE", "DURATION", "FORM", "FREQUENCY", "RATE", "ROUTE_OR_MODE", "STRENGTH"
-        ],
+        "Type": RxNormAttributeType,
         "Score": float,
         "RelationshipScore": float,
         "Id": int,
@@ -326,8 +217,8 @@ RxNormEntityTypeDef = TypedDict(
     {
         "Id": int,
         "Text": str,
-        "Category": Literal["MEDICATION"],
-        "Type": Literal["BRAND_NAME", "GENERIC_NAME"],
+        "Category": RxNormEntityCategory,
+        "Type": RxNormEntityType,
         "Score": float,
         "BeginOffset": int,
         "EndOffset": int,
@@ -339,44 +230,20 @@ RxNormEntityTypeDef = TypedDict(
 )
 
 RxNormTraitTypeDef = TypedDict(
-    "RxNormTraitTypeDef", {"Name": Literal["NEGATION"], "Score": float}, total=False
+    "RxNormTraitTypeDef", {"Name": RxNormTraitName, "Score": float}, total=False
 )
 
-TraitTypeDef = TypedDict(
-    "TraitTypeDef",
-    {"Name": Literal["SIGN", "SYMPTOM", "DIAGNOSIS", "NEGATION"], "Score": float},
-    total=False,
-)
+TraitTypeDef = TypedDict("TraitTypeDef", {"Name": AttributeName, "Score": float}, total=False)
 
 UnmappedAttributeTypeDef = TypedDict(
-    "UnmappedAttributeTypeDef",
-    {
-        "Type": Literal[
-            "MEDICATION",
-            "MEDICAL_CONDITION",
-            "PROTECTED_HEALTH_INFORMATION",
-            "TEST_TREATMENT_PROCEDURE",
-            "ANATOMY",
-            "TIME_EXPRESSION",
-        ],
-        "Attribute": "AttributeTypeDef",
-    },
-    total=False,
+    "UnmappedAttributeTypeDef", {"Type": EntityType, "Attribute": "AttributeTypeDef"}, total=False
 )
 
 ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
     "ComprehendMedicalAsyncJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED",
-            "IN_PROGRESS",
-            "COMPLETED",
-            "PARTIAL_SUCCESS",
-            "FAILED",
-            "STOP_REQUESTED",
-            "STOPPED",
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
